# Changelog

<!--next-version-placeholder-->

## v0.3.0 (2025-06-26)

### Feature

* Helper functions to find namespace/task by name via ctx ([`01cb185`](https://github.com/educationwarehouse/ewok/commit/01cb185a3014e5f9cda387a23e69e6890fefdb5d))

## v0.2.0 (2025-06-20)

### Fix

* Slightly improved `App` usage ([`7b1e863`](https://github.com/educationwarehouse/ewok/commit/7b1e8633992519ec9d52d5ae57e7767abf734938))

### Documentation

* More comprehensive Ewok extensions to `@task()` section ([`0c89a71`](https://github.com/educationwarehouse/ewok/commit/0c89a71f9543defd870a1ff38b7ce1bf4c201439))
* Minor improvements in readme ([`ab66c42`](https://github.com/educationwarehouse/ewok/commit/ab66c42f8810cb5f16c9bb9b33340eb8a9194a57))
* Extended readme explaining a quick start and Ewok extensions to `@task()` ([`26c8a82`](https://github.com/educationwarehouse/ewok/commit/26c8a828fbd515b76d33ce3ca05ec069456d28b5))
* README v1 and LICENSE ([`c7dbb1b`](https://github.com/educationwarehouse/ewok/commit/c7dbb1b5b144ec99241d5674b5a4da65e90804a6))
* Add logo ([`4c44054`](https://github.com/educationwarehouse/ewok/commit/4c44054467fb4129c7f070bffc426277d1840927))

## v0.1.1 (2025-06-20)

### Fix

* More configuration for ewok.App ([`fb9e5c3`](https://github.com/educationwarehouse/ewok/commit/fb9e5c35329fa9c20aeda598bac9dea0bc430c4c))

## v0.1.0 (2025-06-20)

### Feature

* Initial project setup ([`3049a47`](https://github.com/educationwarehouse/ewok/commit/3049a4784e1abf659ccfb098493282a0c62f535e))
